Date: 2021-02-10

# Status
<!-- What is the status, such as draft, proposed, accepted, rejected,
deprecated, superseded, etc.? -->
Draft

# Context
<!-- What is the issue that we're seeing that is motivating this decision or change? -->
Software documentation could benefit from the local newsletter, rss and email
newsletter system.

There are some changes that need to be done though. Instead of creating items
per week, month or year, they should be created each time a release is made.
Also, the template of the newsletter should be different.

# Proposals
<!-- What are the possible solutions to the problem described in the context -->
* Change the template to ...
* Select which changes are added to the changelog
* How do we configure the plugin so it knows it's in changelog mode
* The CI reacts to the tag event to rebuild the documentation and create the
    newsletter.

# Decision
<!-- What is the change that we're proposing and/or doing? -->

# Consequences
<!-- What becomes easier or more difficult to do because of this change? -->
